tryParse static method

MRZResult? tryParse(
  1. List<String?>? input
)

Parse input and return MRZResult instance.

Like parse except that this function returns null where a similar call to parse would throw a MRZException in case of invalid input or unsuccessful parsing

Implementation

static MRZResult? tryParse(List<String?>? input) {
  try {
    return parse(input);
  } on Exception {
    return null;
  }
}