processingLiveImages method
void
processingLiveImages(
- CameraImage cameraImage
Implementation
void processingLiveImages(CameraImage cameraImage) {
///step 1 take a picture
///step 2 process the picture for any faces
///step 3 if face is found then stop the stream and return the image
///step 4 if face is not found then start the stream again
try{
captureTheImage();
}
catch(e){
throw "Error";
}
}