MRZContent class

Constructors

MRZContent({required String documentType, required String countryCode, required String fullNames, required String documentNumber, required String nationalityCountryCode, required String birthDate, required String sex, required String issueOrExpiryDate, required String personalNumber, String? personalNumber2})
const

Properties

birthDate String
final
countryCode String
final
documentNumber String
final
documentType String
final
fullNames String
final
hashCode int
The hash code for this object.
no setterinherited
issueOrExpiryDate String
final
nationalityCountryCode String
final
personalNumber String
final
personalNumber2 String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sex String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited